@@ -1,4 +1,4 @@
-`rmdspe` <- function(forecast, true)
+rmdspe <- function(forecast, true)
 {
      if (length(forecast) != length(true))
          stop("RMDSPE: the lengths of input vectors must be the same.")
